@@ -59,8 +59,9 @@
 //!   - Enables serialization support for serde 0.8
 //! - `blas`
 //!   - Optional and experimental, compatible with Rust stable
-//!   - Enable transparent BLAS support for matrix multiplication. Pluggable
-//!     backend via `blas-sys`.
+//!   - Enable transparent BLAS support for matrix multiplication.
+//!     Uses ``blas-sys`` for pluggable backend, which needs to be configured
+//!     separately.
 //!
 
 #[cfg(feature = "serde")]
@@ -632,7 +633,7 @@ impl<'a, A, D> ArrayBase<ViewRepr<&'a A>, D>
     #[inline]
     fn into_base_iter(self) -> Baseiter<'a, A, D> {
         unsafe {
-            Baseiter::new(self.ptr, self.dim.clone(), self.strides.clone())
+            Baseiter::new(self.ptr, self.dim, self.strides)
         }
     }
 
@@ -681,7 +682,7 @@ impl<'a, A, D> ArrayBase<ViewRepr<&'a mut A>, D>
     #[inline]
     fn into_base_iter(self) -> Baseiter<'a, A, D> {
         unsafe {
-            Baseiter::new(self.ptr, self.dim.clone(), self.strides.clone())
+            Baseiter::new(self.ptr, self.dim, self.strides)
         }
     }
 
